@echo off

:: MSI Generation Tool for Office 365 sources 
:: version 1.1
::
:: release history
:: 1.0: initial version
:: 1.1: added check of Office variant (x32 or x64)
::      updated O365PP2016_Sources.wxs:
::      - take into account variant in package name
::      - modified cab generation parameter for handling sources above 2 GB

:: Parameters

:: Office version, will be retrieved lated in the script
set OFFFICE_VERSION=Unknown

:: configuration file for downloading the sources
set OFFICE_DOWNLOAD_CONFIGURATION_FILE=O365ProPlusRetail_DownloadSources.xml

:: Office variant: 32 -> 32 bits, 64 -> 64 bits
:: It should be identical to the OfficeClientEdition value in the download configuration file
set OFFICE_VARIANT=32


:: if you didn't install the WiX toolset using the provided setup, set this variable to refer to the location of the BIN folder
:: set WIX=C:\Program Files (x86)\WiX Toolset v3.10\
set WIX=C:\Users\803536\Downloads\wix311\

cd %~dp0

:: delete any previous sources

if exist Office (
	del /f /s /q Office >nul
	rd /s /q Office >nul
)

:: delete intermediate files generated for the MSI creation

if exist OfficeSourceFiles.wxs del OfficeSourceFiles.wxs >nul
if exist *.wixobj del *.wixobj >nul
if exist *.wixpdb del *.wixpdb >nul
if exist *.msi del *.msi >nul

:: download the sources

Setup.exe /download %OFFICE_DOWNLOAD_CONFIGURATION_FILE%

if ErrorLevel == 0 goto MSIGeneration

msg * /w "Error while downloading the files, try again later..."

goto End
 
:MSIGeneration

:: retrieve the version number
:: in the downloaded sources folder there is a sub-folder in Office/Data with the version number

for /F %%I in ('dir Office\Data /a:d /b') do set OFFICE_VERSION=%%I

:: retrieve the Office variant

if exist Office\Data\v32.cab set OFFICE_VARIANT=32
if exist Office\Data\v64.cab set OFFICE_VARIANT=64
 
:: generate the list of files to include in the MSI
:: ------------------------------------------------

:: options for Heat.exe
:: -out = output file
:: dir  = folder to take into account
:: -gg  = automatically generate GUID for components when creating the files list 
:: -cg  = name of the components group in the project WXS file
:: -dr  = name of the directory where are added the components in the directory structure defined in the WXS project
:: -var = replace the name of the source directory by a variable
::        SourceDir -> var.SourcesDir
:: -v   = verbose mode

"%WIX%bin\heat.exe" dir ".\Office" -gg -cg OfficeSources -dr TARGETDIR -var var.OfficeSourcesDir -out OfficeSourceFiles.wxs -v > MSI_Generation_Log.txt 
 
:: file list compilation
:: ---------------------

:: options for Candle.exe
:: -out  = output file
:: -d    = set the value for the variables defined in the WXS file 
::         var.SourcesDir -> full path for accessing the files

"%WIX%bin\candle.exe" OfficeSourceFiles.wxs -dOfficeSourcesDir="%~dp0\Office" -out .\ >> MSI_Generation_Log.txt 

:: main project file compilation
:: -----------------------------

:: options for Candle.exe
:: -out  = output file
:: -d    = set the value for the variables defined in the WXS file 
::         var.OFFICE_VERSION -> version number
::         var.OFFICE_VARIANT -> variant x32 or x64, for package name


"%WIX%bin\candle.exe" O365PP2016_Sources.wxs -dOFFICE_VERSION=%OFFICE_VERSION% -dOFFICE_VARIANT=%OFFICE_VARIANT% -out .\ >> MSI_Generation_Log.txt 

:: MSI file creation
:: -----------------

:: options for Light.exe
:: -b   = base path for looking for files
:: -out = name if the MSI file to produce

"%WIX%bin\light.exe" O365PP2016_Sources.wixobj -b .\ OfficeSourceFiles.wixobj -out O365PP2016_Sources_%OFFICE_VERSION%_x%OFFICE_VARIANT%.MSI >> MSI_Generation_Log.txt

msg * /w "MSI generation done!"

:End

pause
 